@@ -23,17 +23,19 @@ class TestPlot(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         cls.credit_data = get_data_credit()
-        sample_data = pd.DataFrame({'col_a': [np.nan, 2, 3, 4],
-                                    'col_b': [np.nan, 'b', 'd', 'd'],
-                                    'col_c': pd.date_range('2021-01-01', '2021-01-04'),
-                                    'col_d': [None, np.nan,
-                                              datetime.date(2021, 4, 2), datetime.date(2021, 4, 2)],
-                                    'col_e': np.nan,
-                                    'col_f': [1.0, 2.0, 3.0, 4.0],
-                                    'col_h': [np.nan, TestEnum.VALUE_A, TestEnum.VALUE_B, TestEnum.VALUE_B],
-                                    'col_i': [None, np.nan, datetime.datetime(2021, 4, 2, 0, 0, 0),
-                                              datetime.datetime(2021, 4, 2, 0, 0, 0)],
-                                    })
+        sample_data = pd.DataFrame({
+            'col_a': [np.nan, 2, 3, 4],
+            'col_b': [np.nan, 'b', 'd', 'd'],
+            'col_c': pd.date_range('2021-01-01', '2021-01-04'),
+            'col_d': [None, np.nan, datetime.date(2021, 4, 2), datetime.date(2021, 4, 2)],
+            'col_e': np.nan,
+            'col_f': [1.0, 2.0, 3.0, 4.0],
+            'col_h': [np.nan, TestEnum.VALUE_A, TestEnum.VALUE_B, TestEnum.VALUE_B],
+            'col_i': [
+                None, np.nan, datetime.datetime(2021, 4, 2, 0, 0, 0),
+                datetime.datetime(2021, 4, 2, 0, 0, 0)
+            ],
+        })
         sample_data.loc[0, 'col_c'] = np.nan
         sample_data['col_g'] = sample_data['col_b'].astype('category')
         cls.sample_data = sample_data
@@ -124,8 +126,8 @@ class TestPlot(unittest.TestCase):
         self.assertTrue(hval.dataframes_match([original, test_series]))
 
     def test_plot_histogram_with_categorical_bug(self):
-        # bug found when no missing values are found in target because we added a <missing> category but
-        # we get an error when calling reorder_categories with extra categories
+        # bug found when no missing values are found in target because we added a <missing>
+        # category but we get an error when calling reorder_categories with extra categories
         credit_data = self.credit_data.copy()
         hplot.plot_histogram_with_categorical(dataframe=credit_data,
                                               numeric_column='credit_amount',
